# CubiCal

CubiCal is a suite of fast radio interferometric calibration routines exploiting complex optimisation.

## Documentation

Documentation can now be found on [readthedocs](http://cubical.readthedocs.io).


## Licence

CubiCal is licensed under the GNU GPL v2.0 Licence.



